riptide library

Classes

Client
A client that can connect to a Server.
ClientConnectedEventArgs
Contains event data for when a non-local client connects to the server.
ClientDisconnectedEventArgs
Contains event data for when a non-local client disconnects from the server.
Connection
Represents a connection to a Server or Client.
ConnectionFailedEventArgs
Contains event data for when a connection attempt to a server fails.
DisconnectedEventArgs
Contains event data for when the client disconnects from a server.
IClient
Defines methods, properties, and events which every transport's client must implement.
IServer
Defines methods, properties, and events which every transport's server must implement.
Message
Provides functionality for converting data to bytes and vice versa.
MessageReceivedEventArgs
Contains event data for when a message is received.
MessageRelayFilter<T extends Enum>
Provides functionality for enabling/disabling automatic message relaying by message type.
MultiThreadedClient
A client which runs in a separate isolate.
MultiThreadedMessageReceivedEventArgs
Contains event data for when a multi threaded server or client receives a message.
MultiThreadedNotifyEventArgs
Contains event data for when a notify message sent by a multi threaded server was delivered or lost.
MultiThreadedNotifyReceivedEventArgs
Contains event data for when a multi threaded server receives a notify message.
MultiThreadedServer
A server which runs in a separate isolate.
MultiThreadedServerConnectedEventArgs
Contains event data for when a client connects to the multi threaded server.
MultiThreadedServerConnectionFailedEventArgs
Contains event data for when a connection to the multi threaded server fails to be fully established.
MultiThreadedServerDisconnectedEventArgs
Contains event data for when a client disconnects from the multi threaded server.
RiptideLogger
Provides functionality for logging messages.
Server
A server that can accept connections from Clients.
ServerConnectedEventArgs
Contains event data for when a client connects to the server.
ServerConnectionFailedEventArgs
Contains event data for when a connection fails to be fully established.
ServerDisconnectedEventArgs
Contains event data for when a client disconnects from the server.
TcpClient
A client which can connect to a TcpServer.
TcpConnection
Represents a connection to a TcpServer or TcpClient.
TcpServer
A server which can accept connections from TcpClients.
UdpClient
A client which can connect to a UdpServer.
UdpConnection
Represents a connection to a UdpServer or UdpClient.
UdpServer
A server which can accept connections from UdpClients

Enums

ConnectionState
The state of a connection
DisconnectReason
The reason for a disconnection.
LogType
Defines log message types.
MessageSendMode
The send mode of a Message.
MultiThreadedTransportType
The transport type for multi threaded server and clients
RejectReason
The reason the connection attempt was rejected.

Typedefs

MultiThreadedConnectionAttemptHandler = void Function(int attemptId, String endPoint, Message connectMessage)
Encapsulates a method that determines whether or not to accept a client's connection attempt on a MultiThreadedServer.