MultiThreadedMessageReceivedEventArgs class

Contains event data for when a multi threaded server or client receives a message.

Constructors

MultiThreadedMessageReceivedEventArgs(int fromClientID, int messageID, Message message)
Initializes event data.

Properties

fromClientID ↔ int
The ID of the client the message was received from. Always 0 for messages received by a client.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ Message
The received message.
getter/setter pair
messageID ↔ int
The ID of the message.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited